@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
 # macports.tcl
-# $Id: macports.tcl 42751 2008-11-30 16:09:10Z jmr@macports.org $
+# $Id: macports.tcl 48231 2009-03-17 07:54:30Z blb@macports.org $
 #
 # Copyright (c) 2002 Apple Computer, Inc.
 # Copyright (c) 2004 - 2005 Paul Guyot, <pguyot@kallisys.net>.
@@ -387,7 +387,7 @@ proc mportinit {{up_ui_options {}} {up_options {}} {up_variations {}}} {
             while {[gets $fd line] >= 0} {
                 if {[regexp {^(\w+)([ \t]+(.*))?$} $line match option ignore val] == 1} {
                     if {[lsearch $bootstrap_options $option] >= 0} {
-                        set macports::$option $val
+                        set macports::$option [string trim $val]
                         global macports::$option
                     }
                 }
@@ -436,7 +436,8 @@ proc mportinit {{up_ui_options {}} {up_options {}} {up_variations {}}} {
     # [macports::getportresourcepath] fails when the first source doesn't
     # contain _resources.
     if {![info exists sources_default]} {
-        return -code error "No default port source specified in $sources_conf"
+        ui_warn "No default port source specified in $sources_conf, using last source as default"
+        set sources_default [lindex $sources end]
     }
 
     if {![info exists sources]} {
@@ -1190,19 +1191,17 @@ proc _porttest {mport depspec} {
 proc _mportinstalled {mport} {
     # Check for the presense of the port in the registry
     set workername [ditem_key $mport workername]
-    set res [$workername eval registry_exists \${portname} \${portversion}]
-    if {$res != 0} {
-        ui_debug "[ditem_key $mport provides] is installed"
-        return 1
-    } else {
+    if {[catch {set reslist [$workername eval registry_installed \${portname}]}]} {
         return 0
+    } else {
+        return [expr [llength $reslist] > 0]
     }
 }
 
 # Determine if a port is active (only for image mode)
 proc _mportactive {mport} {
     set workername [ditem_key $mport workername]
-    if {[catch {set reslist [$workername eval registry_active \${portname}]} res]} {
+    if {[catch {set reslist [$workername eval registry_active \${portname}]}]} {
         return 0
     } else {
         return [expr [llength $reslist] > 0]
@@ -1445,7 +1444,7 @@ proc mportsync {{optionslist {}}} {
             {^file$} {
                 set portdir [macports::getportdir $source]
                 if {[file exists $portdir/.svn]} {
-                    set svn_commandline "[macports::findBinary svn ${macports::autoconf::svn_path}] update --non-interactive ${portdir}"
+                    set svn_commandline "[macports::findBinary svn] update --non-interactive ${portdir}"
                     ui_debug $svn_commandline
                     if {
                         [catch {
@@ -2023,29 +2022,31 @@ proc macports::upgrade {portname dspec variationslist optionslist {depscachename
         # XXX  this sets $version_installed to $version_in_tree even if not installed!!
         set version_installed $version_in_tree
         set revision_installed $revision_in_tree
+        set epoch_installed $epoch_in_tree
         set iname $portname
         # That was a very dirty hack showing how ugly our depencendy and upgrade code is.
         # To get it working when user provides -f, we also need to set the variant to
         # avoid a future failure.
-        set variant ""
+        set variant_installed ""
     } else {
-        # a port could be installed but not activated
-        # so, deactivate all and save newest for activation later
+        # find latest version installed and active version (if any)
         set num 0
         set variant ""
         foreach i $ilist {
             set variant [lindex $i 3]
             set version [lindex $i 1]
             set revision [lindex $i 2]
-            if { $version_installed == {} ||
-                    [rpm-vercomp $version $version_installed] > 0
-                    || ([rpm-vercomp $version $version_installed] == 0
+            set epoch [lindex $i 5]
+            if { $version_installed == {} || $epoch > $epoch_installed ||
+                    ($epoch == $epoch_installed && [rpm-vercomp $version $version_installed] > 0)
+                    || ($epoch == $epoch_installed
+                        && [rpm-vercomp $version $version_installed] == 0
                         && [rpm-vercomp $revision $revision_installed] > 0)} {
                 set iname [lindex $i 0]
                 set version_installed $version
                 set revision_installed $revision
                 set variant_installed $variant
-                set epoch_installed [registry::property_retrieve [registry::open_entry $iname [lindex $i 1] [lindex $i 2] $variant] epoch]
+                set epoch_installed $epoch
                 set num $i
             }
 
@@ -2058,32 +2059,17 @@ proc macports::upgrade {portname dspec variationslist optionslist {depscachename
                 set variant_active $variant
             }
         }
-        if { $anyactive && ([rpm-vercomp $version_installed $version_active] != 0
-                            || [rpm-vercomp $revision_installed $revision_active] != 0
-                            || [string compare $variant_installed $variant_active] != 0)} {
-            # deactivate version
-            if {[catch {portimage::deactivate $active_name ${version_active}_${revision_active}${variant_active} $optionslist} result]} {
-                global errorInfo
-                ui_debug "$errorInfo"
-                ui_error "Deactivating $active_name @${version_active}_${revision_active} failed: $result"
-                return 1
-            }
-        }
-        if { [lindex $num 4] == 0 && 0 == [string compare "image" ${macports::registry.installtype}] } {
-            # activate the latest installed version
-            if {[catch {portimage::activate $iname ${version_installed}_${revision_installed}$variant $optionslist} result]} {
-                global errorInfo
-                ui_debug "$errorInfo"
-                ui_error "Activating $iname @${version_installed}_${revision_installed} failed: $result"
-                return 1
-            }
-        }
     }
 
     # output version numbers
     ui_debug "epoch: in tree: $epoch_in_tree installed: $epoch_installed"
     ui_debug "$portname ${version_in_tree}_$revision_in_tree exists in the ports tree"
-    ui_debug "$iname ${version_installed}_$revision_installed is installed"
+    ui_debug "$iname ${version_installed}_${revision_installed}${variant_installed} is installed"
+    if {$anyactive} {
+        ui_debug "$active_name ${version_active}_${revision_active}${variant_active} is active"
+    } else {
+        ui_debug "no version of $portname is active"
+    }
 
     # set the nodeps option  
     if {![info exists options(ports_nodeps)]} {
@@ -2165,7 +2151,11 @@ proc macports::upgrade {portname dspec variationslist optionslist {depscachename
     }
 
     # check if the variants is present in $version_in_tree
-    set oldvariant $variant
+    if {$anyactive} {
+        set variant $variant_active
+    } else {
+        set variant $variant_installed
+    }
     set variant [split $variant +]
     ui_debug "variants to install $variant"
     if {[info exists portinfo(variants)]} {
@@ -2204,30 +2194,32 @@ proc macports::upgrade {portname dspec variationslist optionslist {depscachename
         return 1
     }
 
+    if { $anyactive && 0 == [string compare "image" ${macports::registry.installtype}] } {
+        # deactivate version_active
+        if {[catch {portimage::deactivate $active_name ${version_active}_${revision_active}${variant_active} $optionslist} result]} {
+            global errorInfo
+            ui_debug "$errorInfo"
+            ui_error "Deactivating $active_name ${version_active}_${revision_active} failed: $result"
+            return 1
+        }
+    }
     # uninstall old ports
     if { $epoch_override == 1 || [info exists options(ports_force)] || 0 != [string compare "image" ${macports::registry.installtype}] } {
         # uninstall old
-        ui_debug "Uninstalling $iname ${version_installed}_$revision_installed$oldvariant"
+        ui_debug "Uninstalling $iname ${version_installed}_${revision_installed}${variant_installed}"
         # we have to force the uninstall in case of dependents
         set force_cur [info exists options(ports_force)]
         set options(ports_force) yes
-        if {[catch {portuninstall::uninstall $iname ${version_installed}_$revision_installed$oldvariant [array get options]} result]} {
+        if {[catch {portuninstall::uninstall $iname ${version_installed}_${revision_installed}${variant_installed} [array get options]} result]} {
             global errorInfo
             ui_debug "$errorInfo"
-            ui_error "Uninstall $iname ${version_installed}_$revision_installed$oldvariant failed: $result"
+            ui_error "Uninstall $iname ${version_installed}_${revision_installed}${variant_installed} failed: $result"
             return 1
         }
         if {!$force_cur} {
             unset options(ports_force)
         }
     } else {
-        # XXX deactivate version_installed
-        if {[catch {portimage::deactivate $iname ${version_installed}_$revision_installed$oldvariant $optionslist} result]} {
-            global errorInfo
-            ui_debug "$errorInfo"
-            ui_error "Deactivating $iname ${version_installed}_$revision_installed failed: $result"
-            return 1
-        }
         if { [info exists options(port_uninstall_old)] } {
             # uninstalling now could fail due to dependents when not forced,
             # because the new version is not installed
@@ -2238,16 +2230,16 @@ proc macports::upgrade {portname dspec variationslist optionslist {depscachename
     if {[catch {set result [mportexec $workername install]} result]} {
         global errorInfo
         ui_debug "$errorInfo"
-        ui_error "Couldn't activate $portname ${version_in_tree}_$revision_in_tree$oldvariant: $result"
+        ui_error "Couldn't activate $portname ${version_in_tree}_${revision_in_tree}: $result"
         return 1
     }
     
     if { [info exists uninstall_later] && $uninstall_later == yes } {
-        ui_debug "Uninstalling $iname ${version_installed}_$revision_installed$oldvariant"
-        if {[catch {portuninstall::uninstall $iname ${version_installed}_$revision_installed$oldvariant $optionslist} result]} {
+        ui_debug "Uninstalling $iname ${version_installed}_${revision_installed}${variant_installed}"
+        if {[catch {portuninstall::uninstall $iname ${version_installed}_${revision_installed}${variant_installed} $optionslist} result]} {
             global errorInfo
             ui_debug "$errorInfo"
-            ui_error "Uninstall $iname ${version_installed}_$revision_installed$oldvariant failed: $result"
+            ui_error "Uninstall $iname ${version_installed}_${revision_installed}${variant_installed} failed: $result"
             return 1
         }
     }
