@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
 # portconfigure.tcl
-# $Id: portconfigure.tcl 42698 2008-11-29 20:38:10Z jmr@macports.org $
+# $Id: portconfigure.tcl 46624 2009-02-09 01:59:59Z ryandesign@macports.org $
 #
 # Copyright (c) 2002 - 2003 Apple Computer, Inc.
 # Copyright (c) 2007 Markus W. Weissmann <mww@macports.org>
@@ -152,6 +152,7 @@ proc configure_start {args} {
         llvm-gcc-4.2 { set name "Mac OS X llvm-gcc 4.2" }
         apple-gcc-3.3 { set name "MacPorts Apple gcc 3.3" }
         apple-gcc-4.0 { set name "MacPorts Apple gcc 4.0" }
+        apple-gcc-4.2 { set name "MacPorts Apple gcc 4.2" }
         macports-gcc-3.3 { set name "MacPorts gcc 3.3" }
         macports-gcc-3.4 { set name "MacPorts gcc 3.4" }
         macports-gcc-4.0 { set name "MacPorts gcc 4.0" }
@@ -315,6 +316,13 @@ proc configure_get_compiler {type} {
                 cpp  { set ret ${prefix}/bin/cpp-apple-4.0 }
             }
         }
+        apple-gcc-4.2 {
+            switch -exact ${type} {
+                cc   { set ret ${prefix}/bin/gcc-apple-4.2 }
+                objc { set ret ${prefix}/bin/gcc-apple-4.2 }
+                cpp  { set ret ${prefix}/bin/cpp-apple-4.2 }
+            }
+        }
         macports-gcc-3.3 {
             switch -exact ${type} {
                 cc  { set ret ${prefix}/bin/gcc-mp-3.3 }
