@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
 # portdestroot.tcl
-# $Id: portdestroot.tcl 42662 2008-11-28 23:18:50Z raimue@macports.org $
+# $Id: portdestroot.tcl 45617 2009-01-19 00:19:52Z raimue@macports.org $
 #
 # Copyright (c) 2002 - 2003 Apple Computer, Inc.
 # Copyright (c) 2004 - 2005 Robert Shaw <rshaw@opendarwin.org>
@@ -88,6 +88,7 @@ namespace eval destroot {
 proc destroot_start {args} {
     global UI_PREFIX prefix portname porturl destroot os.platform destroot.clean portsharepath
     global destroot::oldmask destroot.umask
+    global applications_dir frameworks_dir
     
     ui_msg "$UI_PREFIX [format [msgcat::mc "Staging %s into destroot"] ${portname}]"
 
@@ -101,6 +102,8 @@ proc destroot_start {args} {
     file mkdir "${destroot}"
     if { ${os.platform} == "darwin" } {
         system "cd \"${destroot}\" && ${mtree} -e -U -f [file join ${portsharepath} install macosx.mtree]"
+        file mkdir "${destroot}/${applications_dir}"
+        file mkdir "${destroot}/${frameworks_dir}"
     }
     file mkdir "${destroot}/${prefix}"
     system "cd \"${destroot}/${prefix}\" && ${mtree} -e -U -f [file join ${portsharepath} install prefix.mtree]"
