@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
 # portmain.tcl
-# $Id: portmain.tcl 42662 2008-11-28 23:18:50Z raimue@macports.org $
+# $Id: portmain.tcl 45944 2009-01-25 23:04:56Z blb@macports.org $
 #
 # Copyright (c) 2002 - 2003 Apple Computer, Inc.
 # All rights reserved.
@@ -119,10 +119,7 @@ if {[info exists variations(macosx)] && $variations(macosx) == "+"} {
 
     if {[info exists variations(universal)] && $variations(universal) == "+"} {
         # cannot go into the variant, due to the amount of ports overriding it
-        global configure.universal_target
-        if {[info exists configure.universal_target]} {
-            eval macosx_deployment_target ${configure.universal_target}
-        }
+        eval macosx_deployment_target ${universal_target}
     }
 }
 
