@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
 # portutil.tcl
-# $Id: portutil.tcl 42670 2008-11-29 00:52:55Z jmr@macports.org $
+# $Id: portutil.tcl 46173 2009-01-31 01:48:37Z jmr@macports.org $
 #
 # Copyright (c) 2004 Robert Shaw <rshaw@opendarwin.org>
 # Copyright (c) 2002 Apple Computer, Inc.
@@ -840,7 +840,7 @@ proc reinplace {args}  {
             return -code error "reinplace copy failed"
         }
     
-        for {set i 0} {$i < [llength attributes]} {incr i} {
+        for {set i 0} {$i < [llength $attributes]} {incr i} {
             set opt [lindex $attributes $i]
             incr i
             set arg [lindex $attributes $i]
